API Reference
=============

.. automodule:: fastgpx
   :members:
   :undoc-members:
   :special-members: __init__
   :imported-members:

``geo`` module
--------------

.. automodule:: fastgpx.geo
   :members:
   :undoc-members:
   :special-members: __init__
   :imported-members:

``polyline`` module
-------------------
.. automodule:: fastgpx.polyline
   :members:
   :undoc-members:
   :special-members: __init__
   :imported-members:
